@@ -1,4 +1,4 @@
-/* $Id: msg_limits.h,v 1.24 2004/12/06 14:44:10 bdejean Exp $ */
+/* $Id: msg_limits.h,v 1.26 2006/04/18 20:17:25 gpoo Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -43,17 +43,17 @@ typedef struct _glibtop_msg_limits	glibtop_msg_limits;
 
 struct _glibtop_msg_limits
 {
-	guint64	flags,
-		msgpool,	/* GLIBTOP_IPC_MSGPOOL	*/
-		msgmap,		/* GLIBTOP_IPC_MSGMAP	*/
-		msgmax,		/* GLIBTOP_IPC_MSGMAX	*/
-		msgmnb,		/* GLIBTOP_IPC_MSGMNB	*/
-		msgmni,		/* GLIBTOP_IPC_MSGMNI	*/
-		msgssz,		/* GLIBTOP_IPC_MSGSSZ	*/
-		msgtql;		/* GLIBTOP_IPC_MSGTQL	*/
+	guint64	flags;
+	guint64 msgpool;	/* GLIBTOP_IPC_MSGPOOL	*/
+	guint64 msgmap;		/* GLIBTOP_IPC_MSGMAP	*/
+	guint64 msgmax;		/* GLIBTOP_IPC_MSGMAX	*/
+	guint64 msgmnb;		/* GLIBTOP_IPC_MSGMNB	*/
+	guint64 msgmni;		/* GLIBTOP_IPC_MSGMNI	*/
+	guint64 msgssz;		/* GLIBTOP_IPC_MSGSSZ	*/
+	guint64 msgtql;		/* GLIBTOP_IPC_MSGTQL	*/
 };
 
-#define glibtop_get_msg_limits(msg)	glibtop_get_msg_limits_l(glibtop_global_server, msg)
+void glibtop_get_msg_limits(glibtop_msg_limits *buf);
 
 #if GLIBTOP_SUID_MSG_LIMITS
 #define glibtop_get_msg_limits_r	glibtop_get_msg_limits_p
