@@ -1,4 +1,4 @@
-/* $Id: open.c,v 1.42 2005/12/12 09:38:08 jamesh Exp $ */
+/* $Id: open.c,v 1.43 2006/04/10 08:41:46 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -138,10 +138,10 @@ glibtop_open_l (glibtop *server, const char *program_name,
 
 		sprintf (version, LIBGTOP_VERSION_STRING,
 			 LIBGTOP_VERSION, LIBGTOP_SERVER_VERSION,
-			 sizeof (glibtop_command),
-			 sizeof (glibtop_response),
-			 sizeof (glibtop_union),
-			 sizeof (glibtop_sysdeps));
+			 (guint) sizeof (glibtop_command),
+			 (guint) sizeof (glibtop_response),
+			 (guint) sizeof (glibtop_union),
+			 (guint) sizeof (glibtop_sysdeps));
 
 		size = strlen (version) + 1;
 
