@@ -1,3 +1,4 @@
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/fsusage.h>
@@ -8,7 +9,11 @@
 
 #include <unistd.h>
 #include <sys/param.h>
+#if defined (HAVE_SYS_STATVFS_H)
+#include <sys/statvfs.h>
+#else
 #include <sys/mount.h>
+#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -26,16 +31,24 @@ _glibtop_freebsd_get_fsusage_read_write(glibtop *server,
 				      const char *path)
 {
 	int result;
+#if defined (STAT_STATVFS)
+	struct statvfs sfs;
+#else
 	struct statfs sfs;
+#endif
 
+#if defined (STAT_STATVFS)
+	result = statvfs (path, &sfs);
+#else
 	result = statfs (path, &sfs);
+#endif
 
 	if (result == -1) {
 		return;
 	}
-
+#if !defined(__FreeBSD_kernel__)
 	buf->read = sfs.f_syncreads + sfs.f_asyncreads;
 	buf->write = sfs.f_syncwrites + sfs.f_asyncwrites;
-
+#endif
 	buf->flags |= (1 << GLIBTOP_FSUSAGE_READ) | (1 << GLIBTOP_FSUSAGE_WRITE);
 }
