@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.19 2003/10/19 16:55:32 carlos Exp $ */
+/* $Id: proclist.c,v 1.26 2006/11/27 19:22:45 bdejean Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -21,9 +21,9 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/proclist.h>
 
 #include <glibtop_suid.h>
@@ -60,7 +60,7 @@ glibtop_init_proclist_p (glibtop *server)
 
 unsigned *
 glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
-			int64_t real_which, int64_t arg)
+			gint64 real_which, gint64 arg)
 {
 	struct kinfo_proc *pinfo;
 	unsigned *pids = NULL;
@@ -68,7 +68,7 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 	int i,j;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROCLIST), 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proclist));
 
 	which = (int)(real_which & GLIBTOP_KERN_PROC_MASK);
@@ -83,16 +83,28 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 
 	/* Allocate count objects in the pids_chain array
 	 * Same as malloc is pids is NULL, which it is. */
-	pids = glibtop_realloc_r (server, pids, count * sizeof (unsigned));
+	pids = g_realloc (pids, count * sizeof (unsigned));
 	/* Copy the pids over to this chain */
 	for (i=j=0; i < count; i++) {
+#if (defined(__FreeBSD__) && (__FreeBSD_version >= 500013)) || defined(__FreeBSD_kernel__)
+#define PROC_STAT	ki_stat
+#define PROC_RUID	ki_ruid
+#define PROC_PID	ki_pid
+
+#else
+#define PROC_STAT	kp_proc.p_stat
+#define PROC_RUID	kp_eproc.e_pcred.p_ruid
+#define PROC_PID	kp_proc.p_pid
+
+#endif
+
 		if ((real_which & GLIBTOP_EXCLUDE_IDLE) &&
-		    (pinfo[i].kp_proc.p_stat != SRUN))
+		    (pinfo[i].PROC_STAT != SRUN))
 			continue;
 		else if ((real_which & GLIBTOP_EXCLUDE_SYSTEM) &&
-			 (pinfo[i].kp_eproc.e_pcred.p_ruid == 0))
+			 (pinfo[i].PROC_RUID == 0))
 			continue;
-		pids [j++] = (unsigned) pinfo[i].kp_proc.p_pid;
+		pids [j++] = (unsigned) pinfo[i].PROC_PID;
 	} /* end for */
 	/* Set the fields in buf */
 	buf->number = j;
