@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.29 2004/08/22 19:29:05 bdejean Exp $ */
+/* $Id: procstate.c,v 1.31 2006/11/27 19:22:45 bdejean Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procstate.h>
@@ -72,7 +73,7 @@ glibtop_get_proc_state_p (glibtop *server,
 		return;
 	}
 
-#if defined(__FreeBSD__) && (__FreeBSD_version >= 500013)
+#if (defined(__FreeBSD__) && (__FreeBSD_version >= 500013)) || defined(__FreeBSD_kernel__)
 #define	PROC_COMM	ki_comm
 #define	PROC_SVUID	ki_svuid
 #define	PROC_SVGID	ki_svgid
