@@ -1,4 +1,4 @@
-/* $Id: procuid.c,v 1.21 2005/12/12 09:38:11 jamesh Exp $ */
+/* $Id: procuid.c,v 1.22 2006/11/27 19:22:45 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -77,7 +77,7 @@ glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 		return;
 	}
 
-#if defined(__FreeBSD__) && (__FreeBSD_version >= 500013)
+#if (defined(__FreeBSD__) && (__FreeBSD_version >= 500013)) || defined(__FreeBSD_kernel__)
 
 #define	PROC_RUID	ki_ruid
 #define	PROC_SVUID	ki_svuid
@@ -87,12 +87,8 @@ glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 #define	PROC_PGID	ki_pgid
 #define	PROC_TPGID	ki_tpgid
 #define	PROC_NICE	ki_nice
-#if __FreeBSD_version >= 500013
 #define	PROC_PRIORITY	ki_pri.pri_user
 #else
-#define	PROC_PRIORITY	ki_priority
-#endif
-#else
 
 #define	PROC_RUID	kp_eproc.e_pcred.p_ruid
 #define	PROC_SVUID	kp_eproc.e_pcred.p_svuid
