@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.9 2003/10/19 16:55:46 carlos Exp $ */
+/* $Id: uptime.c,v 1.11 2005/12/12 09:38:13 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,16 +21,15 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/uptime.h>
 
 #include <time.h>
 
 static const unsigned long _glibtop_sysdeps_uptime =
-#if LIBGTOP_VERSION_CODE >= 1001002
-(1L <<GLIBTOP_UPTIME_BOOT_TIME) +
-#endif
-(1L << GLIBTOP_UPTIME_UPTIME);
+(1L <<GLIBTOP_UPTIME_BOOT_TIME)
+| (1L << GLIBTOP_UPTIME_UPTIME);
 
 /* Init function. */
 
@@ -49,9 +48,8 @@ glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 
 	if(!(server->machine.boot))
 	    return;
-#if LIBGTOP_VERSION_CODE >= 1001002
+
 	buf->boot_time = server->machine.boot;
-#endif
 	buf->uptime = time(NULL) - server->machine.boot;
 
 	buf->flags = _glibtop_sysdeps_uptime;
